From 9aa0e259fe64f663d4a861a8adfa3c46353ceab0 Mon Sep 17 00:00:00 2001
From: "Veronica K. B. Olsen" <1619840+vkbo@users.noreply.github.com>
Date: Tue, 1 Sep 2020 23:24:29 +0200
Subject: [PATCH] Added a message box before the document split process is
completed
---
nw/gui/docsplit.py | 19 ++++++++++++++++---
1 file changed, 16 insertions(+), 3 deletions(-)
diff --git a/nw/gui/docsplit.py b/nw/gui/docsplit.py
index edd92b6e..2a292b9f 100644
--- a/nw/gui/docsplit.py
+++ b/nw/gui/docsplit.py
@@ -31,7 +31,7 @@ import nw
from PyQt5.QtCore import Qt
from PyQt5.QtWidgets import (
QDialog, QVBoxLayout, QComboBox, QListWidget, QAbstractItemView,
- QListWidgetItem, QDialogButtonBox, QLabel
+ QListWidgetItem, QDialogButtonBox, QLabel, QMessageBox
)
from nw.constants import nwAlert, nwItemType, nwItemClass, nwItemLayout, nwConst
@@ -107,7 +107,7 @@ class GuiDocSplit(QDialog):
def _doSplit(self):
"""Perform the split of the file, create a new folder in the
same parent folder, and multiple files depending on split level
settings. The old file is not removed in the merge process, and
must be deleted manually.
"""
logger.verbose("GuiDocSplit split button clicked")
@@ -143,7 +143,8 @@ class GuiDocSplit(QDialog):
if i > 0:
finalOrder[i-1][2] = lineNo
- if len(finalOrder) == 0:
+ nFiles = len(finalOrder)
+ if nFiles == 0:
self.theParent.makeAlert((
"No headers found. Nothing to do."
), nwAlert.ERROR)
@@ -159,6 +160,18 @@ class GuiDocSplit(QDialog):
), nwAlert.ERROR)
return
+ if self.mainConf.showGUI:
+ msgBox = QMessageBox()
+ msgRes = msgBox.question(
+ self, "Split Document", (
+ "The document will be split into %d file(s) in a new folder. "
+ "The original document will remain intact.
"
+ "Continue with the splitting process?"
+ ) % nFiles
+ )
+ if msgRes != QMessageBox.Yes:
+ return
+
# Create the folder
fHandle = self.theProject.newFolder(
srcItem.itemName, srcItem.itemClass, srcItem.parHandle
@@ -107,7 +107,7 @@ class GuiDocSplit(QDialog):
"""Perform the split of the file, create a new folder in the
same parent folder, and multiple files depending on split level
- settings. The old file is not removed in the merge process, and
+ settings. The old file is not removed in the split process, and
must be deleted manually.
"""